@@ -5,7 +5,7 @@
  * see https://docs.python.org/3/license.html
  *
  * With modifications:
- * Copyright 2023 The SABnzbd-Team <team@sabnzbd.org>
+ * Copyright 2023 The SABnzbd-Team (sabnzbd.org)
  * Licensed under the GNU GPL version 2 or later.
  *
  * This program is free software; you can redistribute it and/or
@@ -99,10 +99,11 @@ void openssl_init() {
     if(!SSLWantReadError) goto cleanup;
 
 #if defined(_WIN32) || defined(__CYGWIN__)
-    // TODO: more DLL names?
-
-    HMODULE windows_openssl_handle = GetModuleHandle(TEXT("libssl-1_1.dll"));
-    if(!windows_openssl_handle) goto cleanup;
+    HMODULE windows_openssl_handle = GetModuleHandle(TEXT("libssl-3.dll"));
+    if(!windows_openssl_handle) {
+        windows_openssl_handle = GetModuleHandle(TEXT("libssl-1_1.dll"));
+        if(!windows_openssl_handle) goto cleanup;
+    }
 
     *(void**)&SSL_read_ex = GetProcAddress(windows_openssl_handle, "SSL_read_ex");
     *(void**)&SSL_get_error = GetProcAddress(windows_openssl_handle, "SSL_get_error");
@@ -120,12 +121,12 @@ void openssl_init() {
     *(void**)&SSL_get_error = dlsym(openssl_handle, "SSL_get_error");
     *(void**)&SSL_get_shutdown = dlsym(openssl_handle, "SSL_get_shutdown");
 
-    error:
+error:
     if (!openssl_linked() && openssl_handle) dlclose(openssl_handle);
     Py_XDECREF(_ssl_module_path);
 #endif
 
-    cleanup:
+cleanup:
     Py_XDECREF(ssl_module);
     Py_XDECREF(_ssl_module);
     if (!openssl_linked()) {
@@ -223,11 +224,11 @@ static PyObject* unlocked_ssl_recv_into_impl(PySSLSocket *self, Py_ssize_t len,
         goto error;
     }
 
-    done:
+done:
     Py_XDECREF(sock);
     return PyLong_FromSize_t(count);
 
-    error:
+error:
     Py_XDECREF(sock);
     return NULL;
 }
@@ -271,7 +272,7 @@ PyObject* unlocked_ssl_recv_into(PyObject* self, PyObject* args) {
 
     retval = unlocked_ssl_recv_into_impl((PySSLSocket*)Py_ssl_socket, len, &Py_buffer);
 
-    error:
+error:
     PyBuffer_Release(&Py_buffer);
     Py_XDECREF(Py_ssl_socket);
     Py_XDECREF(blocking);
