@@ -1,5 +1,5 @@
 /*
- * Copyright 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
+ * Copyright 2007-2023 The SABnzbd-Team (sabnzbd.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -45,6 +45,7 @@ static void* my_memmem(const void* haystack, size_t haystackLen, const void* nee
     }
     return p;
 }
+
 static inline char* my_memstr(const void* haystack, size_t haystackLen, const char* str, int pointToEnd) {
     size_t len = strlen(str);
     char* p = (char*)my_memmem(haystack, haystackLen, str, len);
@@ -53,7 +54,6 @@ static inline char* my_memstr(const void* haystack, size_t haystackLen, const ch
     return p;
 }
 
-
 PyObject* yenc_decode(PyObject* self, PyObject* Py_bytesarray_obj) {
     // The input/output PyObjects
     (void)self;
@@ -71,6 +71,7 @@ PyObject* yenc_decode(PyObject* self, PyObject* Py_bytesarray_obj) {
     uint32_t crc_yenc = 0;
     size_t yenc_data_length;
     size_t output_len;
+    unsigned long long file_size = 0;
     unsigned long long part_begin = 0;
     unsigned long long part_end = 0;
     unsigned long long part_size = 0;
@@ -113,6 +114,12 @@ PyObject* yenc_decode(PyObject* self, PyObject* Py_bytesarray_obj) {
         retval = NULL;
         goto finish;
     }
+    
+    // Get the size of the reconstructed file
+    start_loc = my_memstr(start_loc, end_loc - start_loc, "size=", 1);
+    if (start_loc) {
+        file_size = atoll(start_loc);
+    }
 
     // Find start of the filename
     start_loc = my_memstr(start_loc, end_loc - start_loc, " name=", 1);
@@ -187,7 +194,9 @@ PyObject* yenc_decode(PyObject* self, PyObject* Py_bytesarray_obj) {
 
     // Parse CRC32
     if (crc_pos && (end_loc - crc_pos) >= 8) {
-        crc_yenc = strtoul(crc_pos, NULL, 16);
+        // Parse up to 64 bit representations of a CRC32 hash, discarding the upper 32 bits
+        // This is necessary become some posts have malformed hashes
+        crc_yenc = strtoull(crc_pos, NULL, 16);
     } else {
         // CRC32 not found - article is invalid
         PyErr_SetString(PyExc_ValueError, "Invalid CRC in footer");
@@ -215,7 +224,7 @@ PyObject* yenc_decode(PyObject* self, PyObject* Py_bytesarray_obj) {
     }
 
     // Build output
-    retval = Py_BuildValue("(S, K, K, N)", Py_output_filename, part_begin, part_size, Py_output_crc);
+    retval = Py_BuildValue("(S, K, K, K, N)", Py_output_filename, file_size, part_begin, part_size, Py_output_crc);
 
 finish:
     Py_XDECREF(Py_output_filename);
